import { Animated, type FlatList, type NativeScrollEvent, type NativeSyntheticEvent } from 'react-native';
import type { WheelPickerProps } from '../components';
/**
 * Custom hook to handle the wheel picker logic
 * @param onChangeValue - Function to handle the value change
 * @param selectedIndex - The index of the selected value
 * @param data - The data to be displayed in the wheel picker
 * @param elementHeight - The height of each element in the wheel picker
 * @param restElements - The number of elements to be displayed above and below the selected element
 * @param decelerationRate - The deceleration rate of the scroll view
 * @param loopCount - The number of times the data should be looped
 * @returns - The necessary props for the wheel picker
 */
declare const useWheelPicker: ({ onChangeValue, selectedIndex, data, elementHeight, restElements, decelerationRate, loopCount, infiniteScroll, initialSelectedIndex, }: Required<Pick<WheelPickerProps, "loopCount" | "onChangeValue" | "selectedIndex" | "data" | "restElements" | "decelerationRate" | "elementHeight" | "infiniteScroll" | "initialSelectedIndex">>) => {
    currentScrollIndex: Animated.AnimatedAddition<string | number>;
    containerHeight: number;
    flatListRef: import("react").RefObject<FlatList<string | null>>;
    arrayElements: (string | number | null)[];
    scrollY: Animated.Value;
    setArrayData: import("react").Dispatch<import("react").SetStateAction<(string | number)[]>>;
    arrayData: (string | number)[];
    handleMomentumScrollEnd: (event: NativeSyntheticEvent<NativeScrollEvent>) => void;
    offsets: number[];
    initialScrollIndex: number;
    onScrollListener: (event: NativeSyntheticEvent<NativeScrollEvent>) => void;
};
export default useWheelPicker;
