import { Animated } from 'react-native';
import type { WheelPickerElementProps } from '../components';
/**
 * Custom hook to handle the wheel picker element logic
 * @param index - The index of the current element
 * @param restElements - The number of elements to be displayed above and below the selected element
 * @param currentScrollIndex - The current scroll index of the wheel picker
 * @param defaultActiveScale - The default scale of the active element
 * @param defaultActiveOpacity - The default opacity of the active element
 * @param elementHeight - The height of each element in the wheel picker
 */
declare const useWheelPickerElement: ({ index, restElements, currentScrollIndex, defaultActiveScale, defaultActiveOpacity, elementHeight, }: Required<Pick<WheelPickerElementProps, "index" | "restElements" | "currentScrollIndex" | "defaultActiveOpacity" | "defaultActiveScale" | "elementHeight">>) => {
    translateY: Animated.AnimatedInterpolation<string | number>;
    opacity: Animated.AnimatedInterpolation<string | number>;
    scale: Animated.AnimatedInterpolation<string | number>;
    rotateX: Animated.AnimatedInterpolation<string | number>;
};
export default useWheelPickerElement;
