/**
 * @param x - index
 * @returns scale value
 */
export declare const scaleFunction: (x: number) => number;
/**
 * Here 2 is the maximum number of visible items
 * @param x - index
 * @returns rotation value
 */
export declare const rotationFunction: (x: number, visible?: number) => number;
/**
 * Here 2 is the maximum number of visible items
 * @param x - index
 * @returns opacity value
 */
export declare const opacityFunction: (x: number, visible?: number) => number;
/**
 * Generates an input range for translating elements along the Y-axis.
 * Function computes the input values for a list of elements, considering a given number of visible elements outside the central element.
 * The input values are symmetrically added to the beginning and end of the range to maintain the balance.
 * @param {number} restElements - The number of visible elements outside the central element.
 * @returns {Array<number>} - An array representing the input range for each item.
 */
export declare const generateInputRange: (restElements: number) => Array<number>;
/**
 * Generates an output range for translating elements along the Y-axis based on a rotation function.
 * Function computes the Y-axis translation for a list of elements, considering a given rotation function. Central element is at index 0, with an initial translation of 0.
 * For each subsequent element, the translation is calculated based on the elementHeight and the provided rotation function.
 * The translation values are symmetrically added to the beginning and end of the range to maintain the balance.
 * @param {number} restElements - The number of visible elements outside the central element.
 * @param {number} elementHeight - The elementHeight of each item in the list.
 * @param {function} rotateFunction - A function that takes an index and returns a rotation value (in radians).
 * @returns {Array<number>} - An array representing the translateY output range for each item.
 */
export declare const generateTranslateYOutputRange: (restElements: number, elementHeight: number, rotateFunction: (x: number) => number) => Array<number>;
/**
 * Generates an output range for a given function.
 * Function computes the output values for a list of elements, considering a given value function.
 * The output values are symmetrically added to the beginning and end of the range to maintain the balance.
 * @param {number} restElements - The number of visible elements outside the central element.
 * @param {function} valueFunction - A function that takes an index and returns a value.
 * @param {number} initialValue - The initial value for the central element.
 * @param {boolean} isRotation - A flag indicating whether the output values are for rotation.
 * @param {boolean} isOpacity - A flag indicating whether the output values are for opacity.
 * @returns {Array<number> | Array<string>} - An array representing the output range for each item.
 */
export declare const generateOutputRange: (restElements: number, valueFunction: (x: number, restElements?: number) => number, initialValue: number | string, isRotation?: boolean, isOpacity?: boolean) => Array<number> | Array<string>;
